@@ -11,7 +11,7 @@ from .stream import Stream
 
 class Client:
 
-    def __init__(self, system_url='https://api.vyze.io/system/', stream_url='ws://api.vyze.io/stream/', app_url='https://api.vyze.io/app/'):
+    def __init__(self, system_url='https://api.vyze.io/system/', stream_url='wss://api.vyze.io/stream', app_url='https://api.vyze.io/app/'):
         self.__app_url = app_url
         self.__stream_url = stream_url
         self.__system_url = system_url
