@@ -1,10 +1,11 @@
 from src import vyze
 
 if __name__ == "__main__":
-    client = vyze.Client(system_url='http://localhost:9131/access/', stream_url='ws://localhost:9131/stream/', app_url='http://localhost:9150/')
-    client.login('Julian', 'goalfoev8')
+    # client = vyze.Client(system_url='http://localhost:9131/access/', stream_url='ws://localhost:9131/stream', app_url='http://localhost:9150/')
+    client = vyze.Client()
+    client.login('jom', 'testtest')
     client.use_universe('geo3')
-    obj = client.create_object(['base.object'], 'b2b981b1a7659088d3bcfe27b9e514fe', 'test_object')
+    obj = client.create_object(['base.object'])
     # print(obj)
     # client.delete_object(obj['id'])
     # obj = client.get_object(obj['id'])
@@ -15,7 +16,7 @@ if __name__ == "__main__":
 
     s.start()
 
-    s.subscribe(obj['id'], 'data', lambda msg: print('data', msg))
+    s.subscribe(obj['id'], 'data', lambda msg: print('data', msg), payload=True)
     s.subscribe(obj['id'], 'name', lambda msg: print('name', msg), payload=True)
 
     client.set_data(obj['id'], bytes('test123', 'UTF8'))
