@@ -6,7 +6,7 @@ from time import sleep
 from src import vyze
 
 if __name__ == "__main__":
-    client = vyze.Client()
+    client = vyze.Client(system_url='http://localhost:9131/access/', stream_url='ws://localhost:9131/stream/', app_url='http://localhost:9150/')
     client.login('jom', 'goalfoev8')
     client.use_universe('geo3')
 
